OC.L10N.register(
    "spreed",
    {
    "a conversation" : "pokalbis",
    "(Duration %s)" : "(Trukmė %s)",
    "You attended a call with {user1}" : "Jūs dalyvavote skambutyje su {user1}",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečias"],
    "You attended a call with {user1} and {user2}" : "Jūs dalyvavote skambutyje su {user1} ir {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Jūs dalyvavote skambutyje su {user1}, {user2} ir {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Jūs dalyvavote skambutyje su {user1}, {user2}, {user3} ir {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Jūs dalyvavote skambutyje su {user1}, {user2}, {user3}, {user4} ir {user5}",
    "_%n other_::_%n others_" : ["dar %n asmuo","dar %n asmenys","dar %n asmenų","dar %n asmuo"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Jūs buvote pakviesti į <strong>pokalbį</strong> arba jums <strong>skambino</strong>",
    "Other activities" : "Kitos veiklos",
    "Talk" : "Pokalbiai",
    "Guest" : "Svečias",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Dabar, dalyvavimui vaizdo ir garso skambučiuose gali būti naudojamos Microsoft Edge ir Safari naršyklės",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Galite siųsti pranešimą visiems dalyviams, pokalbyje parašę \"@all\"",
    "- With the \"arrow-up\" key you can repost your last message" : "- Naudodami klavišą \"rodyklė aukštyn\" galite iš naujo paskelbti savo paskutinę žinutę",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Nuo šiol, Pokalbiuose gali būti komandos. Siųskite pokalbyje žinutę \"/help\" norėdami pamatyti ar jūsų administratorius yra sukonfigūravęs kokias nors komandas",
    "- With projects you can create quick links between conversations, files and other items" : "- Naudodami projektus galite greitai sukurti sąsajas tarp pokalbių, failų bei kitų elementų",
    "- You can now mention guests in the chat" : "- Dabar, pokalbiuose galite minėti svečius",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Dabar, galite tiesiogiai atsakyti į žinutes, suteikdami kitiems naudotojams daugiau konteksto apie ką yra jūsų žinutė",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Dabar, pokalbių ir dalyvių paieška taip pat filtruos ir jūsų esamus pokalbius, todėl bus žymiai lengviau rasti ankstesnius pokalbius",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Nuo šiol, kai turite įdiegtą ratų programėlę, galite pridėti į pokalbius tinkintas naudotojų grupes",
    "- Spice up your messages with emojis from the emoji picker" : "- Praturtinkite savo žinutes šypsenėlėmis iš šypsenėlių parinkiklio",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Dabar šoninėje juostoje galite rasti paskutinių bendrintų elementų apžvalgą",
    "Talk updates ✅" : "Pokalbių programėlės atnaujinimai ✅",
    "Reaction deleted by author" : "Autorius ištrynė reakciją",
    "{actor} created the conversation" : "{actor} sukūrė pokalbį",
    "You created the conversation" : "Jūs sukūrėte pokalbį",
    "System created the conversation" : "Sistema sukūrė pokalbį",
    "An administrator created the conversation" : "Administratorius sukūrė pokalbį",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratorius pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "{actor} set the description" : "{actor} nustatė aprašą",
    "You set the description" : "Jūs nustatėte aprašą",
    "An administrator set the description" : "Administratorius nustatė aprašą",
    "{actor} removed the description" : "{actor} pašalino aprašą",
    "You removed the description" : "Jūs pašalinote aprašą",
    "An administrator removed the description" : "Administratorius pašalino aprašą",
    "You started a silent call" : "Jūs pradėjote tylų skambutį",
    "{actor} started a silent call" : "{actor} pradėjo tylų skambutį",
    "You started a call" : "Jūs pradėjote skambutį",
    "{actor} started a call" : "{actor} pradėjo skambutį",
    "{actor} joined the call" : "{actor} prisijungė prie skambučio",
    "You joined the call" : "Jūs prisijungėte prie skambučio",
    "{actor} left the call" : "{actor} išėjo iš skambučio",
    "You left the call" : "Jūs išėjote iš skambučio",
    "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
    "You unlocked the conversation" : "Jūs atrakinote pokalbį",
    "An administrator unlocked the conversation" : "Administratorius atrakino pokalbį",
    "{actor} locked the conversation" : "{actor} užrakino pokalbį",
    "You locked the conversation" : "Jūs užrakinote pokalbį",
    "An administrator locked the conversation" : "Administratorius užrakino pokalbį",
    "{actor} limited the conversation to the current participants" : "{actor} apribojo pokalbį iki dabartinių dalyvių",
    "You limited the conversation to the current participants" : "Jūs apribojote pokalbį iki dabartinių dalyvių",
    "An administrator limited the conversation to the current participants" : "Administratorius apribojo pokalbį iki dabartinių dalyvių",
    "{actor} opened the conversation to registered users" : "{actor} atvėrė pokalbį registruotiems naudotojams",
    "You opened the conversation to registered users" : "Jūs atvėrėte pokalbį registruotiems naudotojams",
    "An administrator opened the conversation to registered users" : "Administratorius atvėrė pokalbį registruotiems naudotojams",
    "The conversation is now open to everyone" : "Dabar, pokalbis yra atviras visiems",
    "{actor} opened the conversation to everyone" : "{actor} atvėrė pokalbį visiems",
    "You opened the conversation to everyone" : "Jūs atvėrėte pokalbį visiems",
    "{actor} restricted the conversation to moderators" : "{actor} apribojo pokalbį iki moderatorių",
    "You restricted the conversation to moderators" : "Jūs apribojote pokalbį iki moderatorių",
    "{actor} allowed guests" : "{actor} leidžia svečius",
    "You allowed guests" : "Jūs leidote svečius",
    "{actor} disallowed guests" : "{actor} nebeleidžia svečių",
    "You disallowed guests" : "Jūs nebeleidžiate svečių",
    "An administrator disallowed guests" : "Administratorius nebeleidžia svečių",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "An administrator set a password" : "Administratorius nustatė slaptažodį",
    "{actor} removed the password" : "{actor} pašalino slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "An administrator removed the password" : "Administratorius pašalino slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You joined the conversation" : "Jūs prisijungėte prie pokalbio",
    "{actor} joined the conversation" : "{actor} prisijungė prie pokalbio",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "An administrator added {user}" : "Administratorius pridėjo naudotoją {user}",
    "You left the conversation" : "Jūs išėjote iš pokalbio",
    "{actor} left the conversation" : "{actor} išėjo iš pokalbio",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "An administrator removed {user}" : "Administratorius pašalino naudotoją {user}",
    "You accepted the invitation" : "Jūs priėmėte pakvietimą",
    "You declined the invitation" : "Jūs atmetėte pakvietimą",
    "{federated_user} declined the invitation" : "{federated_user} atmetė pakvietimą",
    "{actor} added group {group}" : "{actor} pridėjo grupę {group}",
    "You added group {group}" : "Jūs pridėjote grupę {group}",
    "An administrator added group {group}" : "Administratorius pridėjo grupę {group}",
    "{actor} removed group {group}" : "{actor} pašalino grupę {group}",
    "You removed group {group}" : "Jūs pašalinote grupę {group}",
    "An administrator removed group {group}" : "Administratorius pašalino grupę {group}",
    "{actor} added team {circle}" : "{actor} pridėjo komandą {circle}",
    "You added team {circle}" : "Jūs pridėjote komandą {circle}",
    "An administrator added team {circle}" : "Administratorius pridėjo komandą {circle}",
    "{actor} removed team {circle}" : "{actor} pašalino komandą {circle}",
    "You removed team {circle}" : "Jūs pašalinote komandą {circle}",
    "An administrator removed team {circle}" : "Administratorius pašalino komandą {circle}",
    "{actor} added {phone}" : "{actor} pridėjo {phone}",
    "You added {phone}" : "Jūs pridėjote {phone}",
    "An administrator added {phone}" : "Administratorius pridėjo {phone}",
    "{actor} removed {phone}" : "{actor} pašalino {phone}",
    "You removed {phone}" : "Jūs pašalinote {phone}",
    "An administrator removed {phone}" : "Administratorius pašalino {phone}",
    "{actor} promoted {user} to moderator" : "{actor} paaukštino naudotoją {user} į moderatorius",
    "You promoted {user} to moderator" : "Jūs paaukštinote naudotoją {user} į moderatorius",
    "{actor} promoted you to moderator" : "{actor} paaukštino jus į moderatorius",
    "An administrator promoted you to moderator" : "Administratorius paaukštino jus į moderatorius",
    "An administrator promoted {user} to moderator" : "Administratorius paaukštino naudotoją {user} į moderatorius",
    "{actor} demoted {user} from moderator" : "{actor} pažemino naudotoją {user} iš moderatorių",
    "You demoted {user} from moderator" : "Jūs pažeminote naudotoją {user} iš moderatorių",
    "{actor} demoted you from moderator" : "{actor} pažemino jus iš moderatorių",
    "An administrator demoted you from moderator" : "Administratorius pažemino jus iš moderatorių",
    "An administrator demoted {user} from moderator" : "Administratorius pažemino naudotoją {user} iš moderatorių",
    "{actor} shared a file which is no longer available" : "{actor} pradėjo bendrinti failą, kuris daugiau nebeprieinamas",
    "You shared a file which is no longer available" : "Jūs pradėjote bendrinti failą, kuris daugiau nebeprieinamas",
    "{actor} updated the Matterbridge configuration" : "{actor} atnaujino „Matterbridge“ konfigūraciją",
    "You updated the Matterbridge configuration" : "Jūs atnaujinote „Matterbridge“ konfigūraciją",
    "{actor} removed the Matterbridge configuration" : "{actor} pašalino „Matterbridge“ konfigūraciją",
    "You removed the Matterbridge configuration" : "Jūs pašalinote „Matterbridge“ konfigūraciją",
    "{actor} deleted a message" : "{actor} ištrynė žinutę",
    "You deleted a message" : "Jūs ištrynėte žinutę",
    "{actor} deleted a reaction" : "{actor} ištrynė reakciją",
    "You deleted a reaction" : "Jūs ištrynėte reakciją",
    "{actor} cleared the history of the conversation" : "{actor} išvalė pokalbio istoriją",
    "You cleared the history of the conversation" : "Jūs išvalėte pokalbio istoriją",
    "Message deleted by author" : "Autorius ištrynė žinutę",
    "Message deleted by {actor}" : "{actor} ištrynė žinutę",
    "Message deleted by you" : "Jūs ištrynėte žinutę",
    "Deleted user" : "Ištrintas naudotojas",
    "Unknown number" : "Nežinomas numeris",
    "Administration" : "Administravimas",
    "System" : "Sistema",
    "%s (guest)" : "%s (svečias)",
    "Call ended (Duration {duration})" : "Skambutis baigtas (Trukmė {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis buvo užbaigtas, nes jis pasiekė didžiausią skambučio trukmę (Trukmė {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} užbaigė skambutį (Trukmė {duration})",
    "Talk to %s" : "Kalbėti su %s",
    "An error occurred. Please contact your administrator." : "Įvyko klaida. Susisiekite su administratoriumi.",
    "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
    "No account available to delete." : "Nėra ištrynimui prieinamos paskyros.",
    "Password needs to be set" : "Turi būti nustatytas slaptažodis",
    "File is too big" : "Failas yra per didelis",
    "Invalid file provided" : "Pateiktas neteisingas failas",
    "Invalid image" : "Netinkamas paveikslas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Talk mentions" : "Paminėjimai pokalbiuose",
    "More conversations" : "Daugiau pokalbių",
    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
    "No unread mentions" : "Nėra neskaitytų paminėjimų",
    "You were mentioned" : "Jūs buvote paminėti",
    "Write to conversation" : "Rašyti į pokalbį",
    "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
    "Conversation invitation" : "Pakvietimas į pokalbį",
    "Description" : "Aprašas",
    "Meeting ID" : "Susitikimo ID",
    "Your PIN" : "Jūsų PIN kodas",
    "Password request: %s" : "Slaptažodžio prašymas: %s",
    "Private conversation" : "Privatus pokalbis",
    "Deleted user (%s)" : "Ištrintas naudotojas (%s)",
    "Dismiss notification" : "Atmesti pranešimą",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "New message" : "Naujas laiškas",
    "Reminder" : "Priminimas",
    "Notification" : "Pranešimas",
    "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
    "{user} sent a message in conversation {call}" : "{user} išsiuntė žinutę pokalbyje {call}",
    "A deleted user sent a message in conversation {call}" : "Ištrintas naudotojas išsiuntė žinutę pokalbyje {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (svečias) išsiuntė žinutę pokalbyje {call}",
    "A guest sent a message in conversation {call}" : "Svečias išsiuntė žinutę pokalbyje {call}",
    "{user} replied to your private message" : "{user} atsakė į jūsų privačią žinutę",
    "{user} replied to your message in conversation {call}" : "{user} atsakė į jūsų žinutę pokalbyje {call}",
    "A deleted user replied to your message in conversation {call}" : "Ištrintas naudotojas atsakė į jūsų žinutę pokalbyje {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (svečias) atsakė į jūsų žinutę pokalbyje {call}",
    "A guest replied to your message in conversation {call}" : "Svečias atsakė į jūsų žinutę pokalbyje {call}",
    "{user} mentioned you in a private conversation" : "{user} paminėjo jus privačiame pokalbyje",
    "{user} mentioned you in conversation {call}" : "{user} paminėjo jus pokalbyje {call}",
    "A deleted user mentioned you in conversation {call}" : "Ištrintas naudotojas paminėjo jus pokalbyje {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (svečias) paminėjo jus pokalbyje {call}",
    "A guest mentioned you in conversation {call}" : "Svečias paminėjo jus pokalbyje {call}",
    "View message" : "Rodyti žinutę",
    "Dismiss reminder" : "Atmesti priminimą",
    "View chat" : "Rodyti pokalbį",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "Join call" : "Prisijungti prie skambučio",
    "Answer call" : "Atsiliepti",
    "{user} would like to talk with you" : "{user} norėtų su jumis pakalbėti",
    "Call back" : "Atskambinti",
    "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
    "A group call has started in {call}" : "Grupės skambutis prasidėjo ties {call}",
    "You missed a group call in {call}" : "Jūs praleidote grupės skambutį ties {call}",
    "{email} is requesting the password to access {file}" : "{email} prašo slaptažodžio, kad gautų prieigą prie {file}",
    "{email} tried to request the password to access {file}" : "{email} bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
    "Someone is requesting the password to access {file}" : "Kažkas prašo slaptažodžio, kad gautų prieigą prie {file}",
    "Someone tried to request the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
    "Open settings" : "Atverti nustatymus",
    "error" : "klaida",
    "The certificate of {host} expired" : "{host} liudijimas nebegalioja",
    "Open Talk" : "Atverti pokalbius",
    "Conversations" : "Pokalbiai",
    "Messages in current conversation" : "Žinutės dabartiniame pokalbyje",
    "{user}" : "{user}",
    "Messages" : "Žinutės",
    "Messages in other conversations" : "Žinutės kituose pokalbiuose",
    "Invalid background color" : "Neteisinga fono spalva",
    "Avatar image is not square" : "Avataro paveikslas nėra kvadratinis",
    "Room {number}" : "Kambarys {number}",
    "Something unexpected happened." : "Nutiko kažkas netikėto.",
    "The URL is invalid." : "URL yra neteisingas.",
    "An HTTPS URL is required." : "Reikalingas HTTPS URL.",
    "The email address is invalid." : "El. pašto adresas yra neteisingas.",
    "The language is invalid." : "Neteisinga kalba.",
    "The country is invalid." : "Neteisinga šalis.",
    "Something unexpected happened. Please try again later." : "Nutiko kažkas netikėto. Vėliau bandykite dar kartą.",
    "There is no such account registered." : "Nėra tokios registruotos paskyros.",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Jungtiniai Arabų Emyratai",
    "Afghanistan" : "Afganistanas",
    "Antigua and Barbuda" : "Antigva ir Barbuda",
    "Anguilla" : "Angilija",
    "Albania" : "Albanija",
    "Armenia" : "Armėnija",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Azerbaijan" : "Azerbaidžanas",
    "Bosnia and Herzegovina" : "Bosnija ir Hercegovina",
    "Barbados" : "Barbadosas",
    "Bangladesh" : "Bangladešas",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Fasas",
    "Bulgaria" : "Bulgarija",
    "Bahrain" : "Bahreinas",
    "Burundi" : "Burundis",
    "Benin" : "Beninas",
    "Bermuda" : "Bermudai",
    "Brunei Darussalam" : "Brunėjaus Darusalamas",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahamos",
    "Bhutan" : "Butanas",
    "Botswana" : "Botsvana",
    "Belarus" : "Baltarusija",
    "Belize" : "Belizas",
    "Canada" : "Kanada",
    "Central African Republic" : "Centrinės Afrikos Respublika",
    "Congo" : "Kongas",
    "Switzerland" : "Šveicarija",
    "Chile" : "Čilė",
    "Cameroon" : "Kamerūnas",
    "China" : "Kinija",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Kuba",
    "Christmas Island" : "Kalėdų sala",
    "Cyprus" : "Kipras",
    "Czechia" : "Čekija",
    "Germany" : "Vokietija",
    "Djibouti" : "Džibutis",
    "Denmark" : "Danija",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikos Respublika",
    "Algeria" : "Alžyras",
    "Ecuador" : "Ekvadoras",
    "Estonia" : "Estija",
    "Egypt" : "Egiptas",
    "Eritrea" : "Eritrėja",
    "Spain" : "Ispanija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Suomija",
    "Fiji" : "Fidžis",
    "Falkland Islands (Malvinas)" : "Folklando (Malvinų) salos",
    "Faroe Islands" : "Farerų salos",
    "France" : "Prancūzija",
    "Gabon" : "Gabonas",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltaras",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvinėja",
    "Equatorial Guinea" : "Pusiaujo Gvinėja",
    "Greece" : "Graikija",
    "Guatemala" : "Gvatemala",
    "Guinea-Bissau" : "Bisau Gvinėja",
    "Guyana" : "Gajana",
    "Hong Kong" : "Honkongas",
    "Honduras" : "Hondūras",
    "Croatia" : "Kroatija",
    "Haiti" : "Haitis",
    "Hungary" : "Vengrija",
    "Indonesia" : "Indonezija",
    "Ireland" : "Airija",
    "Israel" : "Izraelis",
    "India" : "Indija",
    "Iraq" : "Irakas",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanija",
    "Japan" : "Japonija",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizija",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribatis",
    "Saint Kitts and Nevis" : "Sent Kitsas ir Nevis",
    "Kuwait" : "Kuveitas",
    "Kazakhstan" : "Kazachstanas",
    "Lebanon" : "Libanas",
    "Liechtenstein" : "Lichtenšteinas",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesotas",
    "Lithuania" : "Lietuva",
    "Luxembourg" : "Liuksemburgas",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Marokas",
    "Monaco" : "Monakas",
    "Montenegro" : "Juodkalnija",
    "Madagascar" : "Madagaskaras",
    "Marshall Islands" : "Maršalo salos",
    "Mali" : "Malis",
    "Myanmar" : "Mianmaras",
    "Mongolia" : "Mongolija",
    "Mauritania" : "Mauritanija",
    "Malta" : "Malta",
    "Mauritius" : "Mauricijus",
    "Maldives" : "Maldyvai",
    "Malawi" : "Malavis",
    "Mexico" : "Meksika",
    "Malaysia" : "Malaizija",
    "Mozambique" : "Mozambikas",
    "Namibia" : "Namibija",
    "New Caledonia" : "Naujoji Kaledonija",
    "Niger" : "Nigeris",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nyderlandai",
    "Norway" : "Norvegija",
    "Nepal" : "Nepalas",
    "Nauru" : "Nauru",
    "New Zealand" : "Naujoji Zelandija",
    "Oman" : "Omanas",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Naujoji Gvinėja",
    "Philippines" : "Filipinai",
    "Pakistan" : "Pakistanas",
    "Poland" : "Lenkija",
    "Pitcairn" : "Pitkerno salos",
    "Puerto Rico" : "Puerto Rikas",
    "Portugal" : "Portugalija",
    "Paraguay" : "Paragvajus",
    "Qatar" : "Kataras",
    "Romania" : "Rumunija",
    "Serbia" : "Serbija",
    "Russian Federation" : "Rusijos Federacija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudo Arabija",
    "Solomon Islands" : "Saliamono salos",
    "Seychelles" : "Seišelių salos",
    "Sudan" : "Sudanas",
    "Sweden" : "Švedija",
    "Singapore" : "Singapūras",
    "Slovenia" : "Slovėnija",
    "Slovakia" : "Slovakija",
    "Sierra Leone" : "Siera Leonė",
    "Senegal" : "Senegalas",
    "Somalia" : "Somalis",
    "Suriname" : "Surinamas",
    "South Sudan" : "Pietų Sudanas",
    "El Salvador" : "Salvadoras",
    "Syrian Arab Republic" : "Sirijos Arabų Respublika",
    "Turks and Caicos Islands" : "Terkso ir Kaikoso salos",
    "Chad" : "Čadas",
    "Togo" : "Togas",
    "Thailand" : "Tailandas",
    "Tajikistan" : "Tadžikistanas",
    "Timor-Leste" : "Rytų Timoras",
    "Turkmenistan" : "Turkmėnistanas",
    "Tunisia" : "Tunisas",
    "Tonga" : "Tongų",
    "Turkey" : "Turkija",
    "Trinidad and Tobago" : "Trinidadas ir Tobagas",
    "Tanzania, United Republic of" : "Tanzanijos Jungtinė Respublika",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Jungtinių Valstijų nuošalios mažosios salos",
    "United States of America" : "Jungtinės Amerikos Valstijos",
    "Uruguay" : "Urugvajus",
    "Uzbekistan" : "Uzbekistanas",
    "Viet Nam" : "Vietnamas",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemenas",
    "South Africa" : "Pietų Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabvė",
    "Background blur" : "Fono suliejimas",
    "Federation" : "Federacija",
    "Error: Cannot connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
    "Error: Certificate expired" : "Klaida: Liudijimas nebegalioja",
    "Could not get version" : "Nepavyko gauti versijos",
    "Error: Unknown error occurred" : "Klaida: Įvyko nežinoma klaida",
    "SIP configuration" : "SIP konfigūracija",
    "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
    "Conversation not found" : "Pokalbis nerastas",
    "Chat, video & audio-conferencing using WebRTC" : "Pokalbiai, vaizdo ir garso konferencijos naudojant WebRTC",
    "Leave call" : "Išeiti iš skambučio",
    "Stay in call" : "Pasilikti skambutyje",
    "Discuss this file" : "Aptarkite šį failą",
    "Share this file with others to discuss it" : "Bendrinti šį failą su kitais, norint jį aptarti",
    "Share this file" : "Bendrinti šį failą",
    "Join conversation" : "Prisijungti prie pokalbio",
    "Request password" : "Prašyti slaptažodžio",
    "Error requesting the password." : "Klaida prašant slaptažodžio.",
    "This conversation has ended" : "Šis pokalbis pasibaigė",
    "Error occurred when joining the conversation" : "Prisijungiant prie pokalbio įvyko klaida",
    "Everyone" : "Visi",
    "Users and moderators" : "Naudotojai ir moderatoriai",
    "Moderators only" : "Tik moderatoriai",
    "Disable calls" : "Išjungti skambučius",
    "Save changes" : "Įrašyti pakeitimus",
    "Saving …" : "Įrašoma …",
    "Saved!" : "Įrašyta!",
    "Limit to groups" : "Apriboti iki grupių",
    "Guests can still join public conversations." : "Svečiai vis tiek gali prisijungti prie viešų pokalbių.",
    "When a call has started, everyone with access to the conversation can join the call." : "Prasidėjus skambučiui, visi, turintys prieigą prie pokalbio, gali prisijungti prie skambučio.",
    "Description is not provided" : "Aprašas nepateiktas",
    "Enabled" : "Įjungta",
    "Disabled" : "Išjungta",
    "State" : "Būsena",
    "Name" : "Vardas",
    "Last error" : "Paskutinė klaida",
    "Total errors count" : "Bendras klaidų skaičius",
    "Beta" : "Beta",
    "Permissions" : "Leidimai",
    "All messages" : "Visos žinutės",
    "@-mentions only" : "Tik @ paminėjimai",
    "Off" : "Išjungta",
    "General settings" : "Bendri nustatymai",
    "Integration into other apps" : "Integracija į kitas programėles",
    "Allow conversations on files" : "Leisti pokalbius failuose",
    "Allow conversations on public shares for files" : "Leisti pokalbius viešai bendrinamuose failuose",
    "Enable encryption" : "Įjungti šifravimą",
    "Pending" : "Laukiantis",
    "Error" : "Klaida",
    "Blocked" : "Blokuota",
    "Active" : "Aktyvi",
    "Expired" : "Nebegalioja",
    "Never" : "Niekada",
    "The account could not be deleted. Please try again later." : "Nepavyko ištrinti paskyros. Vėliau bandykite dar kartą.",
    "URL of this Nextcloud instance" : "Šio Nextcloud egzemplioriaus URL",
    "Email of the user" : "Naudotojo el. paštas",
    "Language" : "Kalba",
    "Country" : "Šalis",
    "Status" : "Būsena",
    "Created at" : "Sukurta",
    "Expires at" : "Baigia galioti",
    "Yes" : "Taip",
    "No" : "Ne",
    "_%n user_::_%n users_" : ["%n naudotojas","%n naudotojai","%n naudotojų","%n naudotojas"],
    "Installed version: {version}" : "Įdiegta versija: {version}",
    "Downloading …" : "Atsisiunčiama…",
    "Matterbridge integration" : "„Matterbridge“ integracija",
    "Enable Matterbridge integration" : "Įjungti „Matterbridge“ integraciją",
    "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
    "Delete this server" : "Ištrinti šį serverį",
    "Test this server" : "Išbandyti šį serverį",
    "SIP configuration saved!" : "SIP konfigūracija įrašyta!",
    "Phone number (Country)" : "Telefono numeris (Šalis)",
    "Available features" : "Prieinamos ypatybės",
    "Error code" : "Klaidos kodas",
    "STUN server URL" : "STUN serverio URL",
    "The server address is invalid" : "Serverio adresas yra neteisingas",
    "STUN settings saved" : "STUN nustatymai įrašyti",
    "STUN servers" : "STUN serveriai",
    "Add a new STUN server" : "Pridėti naują STUN serverį",
    "{option1} and {option2}" : "{option1} ir {option2}",
    "{option} only" : "tik {option}",
    "TURN server URL" : "TURN serverio URL",
    "TURN server secret" : "TURN serverio paslaptis",
    "TURN server protocols" : "TURN serverio protokolai",
    "TURN settings saved" : "TURN nustatymai įrašyti",
    "TURN servers" : "TURN serveriai",
    "Add a new TURN server" : "Pridėti naują TURN serverį",
    "Failed" : "Nepavyko",
    "OK" : "Gerai",
    "Checking …" : "Tikrinama…",
    "Assignment method" : "Priskyrimo metodas",
    "Automatically assign participants" : "Automatiškai priskirti dalyvius",
    "Manually assign participants" : "Rankiniu būdu priskirti dalyvius",
    "Allow participants to choose" : "Leisti dalyviams pasirinkti",
    "Confirm" : "Patvirtinti",
    "Reset" : "Atstatyti",
    "Room {roomNumber}" : "Kambarys {roomNumber}",
    "Cancel" : "Atsisakyti",
    "Unassigned participants" : "Nepriskirti dalyviai",
    "Back" : "Atgal",
    "Assign" : "Priskirti",
    "Now" : "Dabar",
    "Unknown error occurred" : "Įvyko nežinoma klaida",
    "Meeting" : "Susitikimas",
    "Loading …" : "Įkeliama…",
    "From" : "Nuo",
    "To" : "Kam",
    "Calendar" : "Kalendorius",
    "Attendees" : "Kviestiniai",
    "Save" : "Įrašyti",
    "Search participants" : "Ieškoti dalyvių",
    "No results" : "Rezultatų nėra",
    "Done" : "Atlikta",
    "Raise hand" : "Pakelti ranką",
    "Raise hand (R)" : "Pakelti ranką (R)",
    "Lower hand" : "Nuleisti ranką",
    "Lower hand (R)" : "Nuleisti ranką (R)",
    "Grid view" : "Tinklelio rodinys",
    "This conversation is read-only" : "Šis pokalbis yra tik skaitymui",
    "Conversation not found or not joined" : "Pokalbis nerastas arba prie jo neprisijungta",
    "Connection failed" : "Ryšys patyrė nesėkmę",
    "Reload" : "Įkelti iš naujo",
    "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
    "A participant raised their hand." : "Dalyvis pakėlė ranką.",
    "Previous page of videos" : "Ankstesnis vaizdo įrašų puslapis",
    "Next page of videos" : "Kitas vaizdo įrašų puslapis",
    "Connecting …" : "Jungiamasi…",
    "Calling …" : "Skambinama…",
    "Waiting for {user} to join the call" : "Laukiama, kol {user} prisijungs prie skambučio",
    "Waiting for others to join the call …" : "Laukiama, kol kiti prisijungs prie skambučio…",
    "You can invite others in the participant tab of the sidebar" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje arba bendrindami šią nuorodą, skirtą pakviesti kitus asmenis!",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "Copy link" : "Kopijuoti nuorodą",
    "You are not allowed to enable audio" : "Jums neleidžiama įjungti garsą",
    "No audio. Click to select device" : "Nėra garso. Spustelėkite norėdami pasirinkti įrenginį",
    "Mute audio" : "Nutildyti garsą",
    "Mute audio (M)" : "Nutildyti garsą (M)",
    "Unmute audio" : "Įjungti garsą",
    "Unmute audio (M)" : "Įjungti garsą (M)",
    "None" : "Nėra",
    "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
    "Error while accessing camera: It is likely in use by another program" : "Klaida gaunant prieigą prie kameros: Tikėtina, kad ją naudoja kita programa",
    "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
    "You are not allowed to enable video" : "Jums neleidžiama įjungti vaizdą",
    "No video. Click to select device" : "Nėra vaizdo. Spustelėkite norėdami pasirinkti įrenginį",
    "Disable video" : "Išjungti vaizdą",
    "Disable video (V)" : "Išjungti vaizdą (V)",
    "Enable video" : "Įjungti vaizdą",
    "Enable video (V)" : "Įjungti vaizdą (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą – Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (V) – Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "You" : "Jūs",
    "Mute" : "Nutildyti",
    "Show screen" : "Rodyti ekraną",
    "Connection could not be established …" : "Nepavyko užmegzti ryšio…",
    "Connection was lost and could not be re-established …" : "Ryšys nutrūko ir jo nepavyko užmegzti iš naujo…",
    "Connection could not be established. Trying again …" : "Nepavyko užmegzti ryšio. Bandoma dar kartą…",
    "Connection lost. Trying to reconnect …" : "Nutrūko ryšys. Bandoma prisijungti iš naujo…",
    "Connection problems …" : "Ryšio problemos…",
    "Collapse" : "Suskleisti",
    "Expand" : "Išskleisti",
    "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
    "Scroll to bottom" : "Slinkti į apačią",
    "Public conversation" : "Viešas pokalbis",
    "Favorite" : "Mėgstamas",
    "Date:" : "Data:",
    "Note:" : "Pastaba:",
    "Hide details" : "Slėpti išsamesnę informaciją",
    "Show details" : "Rodyti išsamiau",
    "Error while updating conversation name" : "Klaida atnaujinant pokalbio pavadinimą",
    "Error while updating conversation description" : "Klaida atnaujinant pokalbio aprašą",
    "Enter a name for this conversation" : "Įveskite šio pokalbio pavadinimą",
    "Edit conversation name" : "Taisyti pokalbio pavadinimą",
    "Edit conversation description" : "Taisyti pokalbio aprašą",
    "Enter a description for this conversation" : "Įveskite šio pokalbio aprašą",
    "Disable" : "Išjungti",
    "Enable" : "Aktyvuoti",
    "Please select a valid PNG or JPG file" : "Pasirinkite tinkamą PNG ar JPG failą",
    "Choose" : "Pasirinkite",
    "The file must be a PNG or JPG" : "Failas privalo būti PNG ar JPG tipo",
    "All permissions" : "Visi leidimai",
    "Restricted" : "Apribota",
    "Advanced permissions" : "Išplėstiniai leidimai",
    "Edit permissions" : "Taisyti leidimus",
    "Conversation settings" : "Pokalbio nustatymai",
    "Basic Info" : "Pagrindinė informacija",
    "Personal" : "Asmeniniai",
    "Setup overview" : "Sąrankos apžvalga",
    "Danger zone" : "Pavojinga zona",
    "Do you really want to leave \"{displayName}\"?" : "Ar tikrai norite išeiti iš „{displayName}“?",
    "Leave conversation" : "Išeiti iš pokalbio",
    "Delete conversation" : "Ištrinti pokalbį",
    "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
    "Error while deleting conversation" : "Klaida ištrinant pokalbį",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Ar tikrai norite ištrinti visas žinutes, esančias „{displayName}“?",
    "Error while clearing chat history" : "Klaida išvalant pokalbio istoriją",
    "Be careful, these actions cannot be undone." : "Būkite atsargūs, šių veiksmų nebegalėsite atšaukti.",
    "Permanently delete this conversation." : "Ištrinti šį pokalbį visam laikui.",
    "_%n hour_::_%n hours_" : ["%n valanda","%n valandos","%n valandų","%n valanda"],
    "_%n day_::_%n days_" : ["%n diena","%n dienos","%n dienų","%n diena"],
    "_%n week_::_%n weeks_" : ["%n savaitė","%n savaitės","%n savaičių","%n savaitė"],
    "Password copied to clipboard" : "Slaptažodis nukopijuotas į iškarpinę",
    "Password could not be copied" : "Nepavyko nukopijuoti slaptažodžio",
    "Allow guests to join this conversation via link" : "Leisti svečiams prisijungti prie šio pokalbio per nuorodą",
    "Password protection" : "Apsauga slaptažodžiu",
    "Set a password" : "Nustatyti slaptažodį",
    "Save password" : "Įrašyti slaptažodį",
    "Copy password" : "Kopijuoti slaptažodį",
    "Guests are allowed to join this conversation via link" : "Svečiams leidžiama prisijungti prie šio pokalbio per nuorodą",
    "Guests are not allowed to join this conversation" : "Svečiams neleidžiama prisijungti prie šio pokalbio",
    "Resend invitations" : "Siųsti pakvietimus iš naujo",
    "This conversation is open to registered users" : "Šis pokalbis yra atviras registruotiems naudotojams",
    "Open conversation" : "Atverti pokalbį",
    "Invalid language" : "Neteisinga kalba",
    "Start time: {date}" : "Pradžios laikas: {date}",
    "Start time has been updated" : "Pradžios laikas atnaujintas",
    "Error occurred while updating start time" : "Atnaujinant pradžios laiką, įvyko klaida",
    "Start time (optional)" : "Pradžios laikas (nebūtinas)",
    "Error occurred when locking the conversation" : "Užrakinant pokalbį, įvyko klaida",
    "Error occurred when unlocking the conversation" : "Atrakinant pokalbį, įvyko klaida",
    "Lock conversation" : "Užrakinti pokalbį",
    "Edit" : "Taisyti",
    "More information" : "Daugiau informacijos",
    "Delete" : "Ištrinti",
    "unknown state" : "nežinoma būsena",
    "Log content" : "Žurnalo turinys",
    "Notifications" : "Pranešimai",
    "Notify about calls in this conversation" : "Pranešti apie skambučius šiame pokalbyje",
    "Important conversation" : "Svarbus pokalbis",
    "Join" : "Prisijungti",
    "Error while creating the conversation" : "Klaida kuriant pokalbį",
    "Create a new conversation" : "Sukurti naują pokalbį",
    "Join open conversations" : "Prisijungti prie atvirų pokalbių",
    "Create conversation" : "Sukurti pokalbį",
    "Enter your name" : "Įveskite savo vardą",
    "Submit name and join" : "Pateikti vardą ir prisijungti",
    "Do you already have an account?" : "Ar jau turite paskyra?",
    "Log in" : "Prisijungti",
    "Import a file" : "Importuoti failą",
    "Browse" : "Naršyti",
    "This might take a moment" : "Tai gali šiek tiek užtrukti",
    "Phone number could not be called: {error}" : "Nepavyko paskambinti telefono numeriu: {error}",
    "Phone number could not be called" : "Nepavyko paskambinti telefono numeriu",
    "Creating the conversation …" : "Kuriamas pokalbis…",
    "Mark as read" : "Žymėti kaip skaitytą",
    "Mark as unread" : "Žymėti kaip neskaitytą",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
    "Decline invitation" : "Atmesti pakvietimą",
    "Accept invitation" : "Priimti pakvietimą",
    "Home" : "Namai",
    "No matches found" : "Nerasta jokių atitikmenų",
    "You have no unread messages." : "Jūs neturite neskaitytų žinučių.",
    "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
    "Conversation list" : "Pokalbių sąrašas",
    "Unread messages" : "Neskaitytos žinutės",
    "Clear filters" : "Išvalyti filtrus",
    "Back to conversations" : "Atgal į pokalbius",
    "Clear filter" : "Išvalyti filtrą",
    "Users" : "Naudotojai",
    "Groups" : "Grupės",
    "Teams" : "Komandos",
    "New private conversation" : "Naujas privatus pokalbis",
    "Open conversations" : "Atviri pokalbiai",
    "No search results" : "Nėra paieškos rezultatų",
    "Users, groups and teams" : "Naudotojai, grupės ir komandos",
    "Users and groups" : "Naudotojai ir grupės",
    "Users and teams" : "Naudotojai ir komandos",
    "Groups and teams" : "Grupės ir komandos",
    "Other sources" : "Kiti šaltiniai",
    "New group conversation" : "Naujas grupės pokalbis",
    "The meeting will start soon" : "Susitikimas netrukus prasidės",
    "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
    "Select microphone" : "Pasirinkti mikrofoną",
    "No microphone available" : "Nėra prieinamo mikrofono",
    "Select camera" : "Pasirinkti kamerą",
    "No camera available" : "Nėra prieinamos kameros",
    "Select a device" : "Pasirinkti įrenginį",
    "Playing …" : "Atkuriama…",
    "Test speakers" : "Išbandyti garsiakalbius",
    "Devices" : "Įrenginiai",
    "Backgrounds" : "Fonai",
    "No audio" : "Nėra jokio garso",
    "No camera" : "Nėra kameros",
    "Calls are not supported in your browser" : "Jūsų naršyklėje skambučiai yra nepalaikomi",
    "Access to microphone is only possible with HTTPS" : "Prieiga prie mikrofono yra įmanoma tik naudojant HTTPS",
    "Access to microphone was denied" : "Prieiga prie mikrofono buvo uždrausta",
    "Error while accessing microphone" : "Klaida gaunant prieigą prie mikrofono",
    "Access to camera is only possible with HTTPS" : "Prieiga prie kameros yra įmanoma tik naudojant HTTPS",
    "Apply settings" : "Taikyti nustatymus",
    "Select a file" : "Pasirinkti failą",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Upload" : "Įkelti",
    "Files" : "Failai",
    "24 hours" : "24 valandos",
    "7 days" : "7 dienos",
    "Message text copied to clipboard" : "Žinutės tekstas nukopijuotas į iškarpinę",
    "Message text could not be copied" : "Nepavyko nukopijuoti žinutės teksto",
    "A reminder was successfully removed" : "Priminimas buvo sėkmingai pašalintas",
    "Error occurred when removing a reminder" : "Šalinant priminimą, įvyko klaida",
    "Error occurred when creating a reminder" : "Kuriant priminimą įvyko klaida",
    "Reply" : "Atsakyti",
    "More actions" : "Daugiau veiksmų",
    "Set reminder" : "Nustatyti priminimą",
    "Reply privately" : "Atsakyti privačiai",
    "Edit message" : "Taisyti laišką",
    "Copy message link" : "Kopijuoti žinutės nuorodą",
    "Go to file" : "Pereiti į failą",
    "Download file" : "Atsisiųsti failą",
    "Forward message" : "Persiųsti žinutę",
    "Translate" : "Verskite",
    "Set custom reminder" : "Nustatyti tinkintą priminimą",
    "Close reactions menu" : "Užverti reakcijų meniu",
    "React with {emoji}" : "Reaguoti naudojant {emoji}",
    "React with another emoji" : "Reaguoti kita šypsenėle",
    "Error while forwarding message" : "Klaida persiunčiant žinutę",
    "Dismiss" : "Atmesti",
    "The message could not be translated" : "Nepavyko išversti laiško",
    "Translation copied to clipboard" : "Vertimas nukopijuotas į iškarpinę",
    "Translation could not be copied" : "Nepavyko nukopijuoti vertimo",
    "Translate message" : "Versti laišką",
    "Source language to translate from" : "Pradinė kalba, iš kurios versti",
    "Translate from" : "Versti iš",
    "Target language to translate into" : "Paskirties kalbą, į kurią versti",
    "Translate to" : "Versti į",
    "Translating" : "Verčiama",
    "Send now" : "Siųsti dabar",
    "Message sent" : "Žinutė išsiųsta",
    "Message deleted successfully" : "Žinutė sėkmingai ištrinta",
    "Your browser does not support playing audio files" : "Jūsų naršyklė nepalaiko garso įrašo failų atkūrimo",
    "Contact" : "Adresatas",
    "Remove {fileName}" : "Šalinti {fileName}",
    "You are not allowed to share files" : "Jums neleidžiama bendrinti failų",
    "You cannot send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį",
    "Poll" : "Apklausa",
    "See results" : "Rodyti rezultatus",
    "Reactions" : "Reakcijos",
    "and {participant}" : "ir {participant}",
    "_and %n other participant_::_and %n other participants_" : ["ir dar %n dalyvis","ir dar %n dalyviai","ir dar %n dalyvių","ir dar %n dalyvis"],
    "Show all reactions" : "Rodyti visas reakcijas",
    "Add more reactions" : "Pridėti daugiau reakcijų",
    "No messages" : "Nėra laiškų",
    "Unpin" : "Atsegti",
    "Cancel search" : "Atsisakyti paieškos",
    "Add a phone number" : "Pridėti telefono numerį",
    "Create a new group conversation" : "Sukurti naują grupės pokalbį",
    "Add participants" : "Pridėti dalyvius",
    "Allow guests to join via link" : "Leisti svečiams prisijungti per nuorodą",
    "This conversation has been locked" : "Šis pokalbis užrakintas",
    "Joining conversation …" : "Prisijungiama prie pokalbio…",
    "Send message" : "Siųsti žinutę",
    "Send without notification" : "Siųsti be pranešimo",
    "File to share" : "Failas, kurį bendrinti",
    "Add emoji" : "Pridėti šypsenėlę",
    "Send later" : "Siųsti vėliau",
    "Share from Files" : "Bendrinti iš failų",
    "Upload from device" : "Įkelti iš įrenginio",
    "Create new poll" : "Sukurti naują apklausą",
    "Microphone either not available or disabled in settings" : "Mikrofonas arba neprieinamas, arba išjungtas nustatymuose",
    "New file" : "Naujas failas",
    "Error while creating file" : "Klaida kuriant failą",
    "Create and share a new file" : "Sukurti ir bendrinti naują failą",
    "Name of the new file" : "Naujo failo pavadinimas",
    "Create file" : "Sukurti failą",
    "Someone is typing …" : "Kažkas rašo…",
    "{user1} is typing …" : "{user1} rašo…",
    "{user1} and {user2} are typing …" : "{user1} ir {user2} rašo…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} ir {user3} rašo…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} ir dar %n žmogus rašo…","{user1}, {user2}, {user3} ir dar %n žmonės rašo…","{user1}, {user2}, {user3} ir dar %n žmonių rašo…","{user1}, {user2}, {user3} ir dar %n žmogus rašo…"],
    "Add more files" : "Pridėti daugiau failų",
    "Send" : "Siųsti",
    "Enable the microphone" : "Įjungti mikrofoną",
    "Enable the camera" : "Įjungti kamerą",
    "Share the screen" : "Bendrinti ekraną",
    "Create poll" : "Sukurti apklausą",
    "Question" : "Klausimas",
    "Answers" : "Atsakymai",
    "Add answer" : "Pridėti atsakymą",
    "Settings" : "Nustatymai",
    "Anonymous poll" : "Anoniminė apklausa",
    "Hide list of participants" : "Slėpti dalyvių sąrašą",
    "Show list of participants" : "Rodyti dalyvių sąrašą",
    "Back to main room" : "Atgal į pagrindinį kambarį",
    "Disable lobby" : "Išjungti laukimo salę",
    "moderator" : "moderatorius",
    "guest" : "svečias",
    "Call rejected" : "Skambutis atmestas",
    "Raised their hand" : "Pakėlė ranką",
    "Remove group and members" : "Šalinti grupę ir narius",
    "Remove team and members" : "Šalinti komandą ir narius",
    "Remove participant" : "Šalinti dalyvį",
    "Demote from moderator" : "Pažeminti iš moderatorių",
    "Promote to moderator" : "Paaukštinti į moderatorius",
    "Resend invitation" : "Siųsti pakvietimą iš naujo",
    "Copy phone number" : "Kopijuoti telefono numerį",
    "Reset custom permissions" : "Atstatyti tinkintus leidimus",
    "Grant all permissions" : "Suteikti visus leidimus",
    "Remove all permissions" : "Šalinti visus leidimus",
    "Remove" : "Šalinti",
    "Add users or groups" : "Pridėti naudotojus ar grupes",
    "Add users" : "Pridėti naudotojus",
    "Add groups" : "Pridėti grupes",
    "Add other sources" : "Pridėti kitus šaltinius",
    "Add emails" : "Pridėti el. paštus",
    "Integrations" : "Integracijos",
    "Searching …" : "Ieškoma…",
    "Search for more users" : "Ieškoti daugiau naudotojų",
    "Participants" : "Dalyviai",
    "Participants ({count})" : "Dalyviai ({count})",
    "Open chat" : "Atverti pokalbį",
    "Chat" : "Pokalbis",
    "Details" : "Išsamiau",
    "Shared items" : "Bendrinami elementai",
    "No results found" : "Nerasta jokių rezultatų",
    "Load more results" : "Įkelti daugiau rezultatų",
    "Projects" : "Projektai",
    "No shared items" : "Nėra bendrinamų elementų",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
    "Phone numbers" : "Telefono numeriai",
    "Notification settings" : "Pranešimų nustatymai",
    "Default language" : "Numatytoji kalba",
    "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
    "Privacy" : "Privatumas",
    "Attachments folder" : "Priedų aplankas",
    "Search" : "Ieškoti",
    "Shortcuts while in a call" : "Spartieji klavišai dalyvaujant skambutyje",
    "Camera on and off" : "Įjungti ar išjungti kamerą",
    "Microphone on and off" : "Įjungti ar išjungti mikrofoną",
    "Raise or lower hand" : "Pakelti ar nuleisti ranką",
    "Start call" : "Pradėti skambutį",
    "You are not allowed to enable screensharing" : "Jums neleidžiama įjungti ekrano bendrinimo",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "Disable background blur" : "Išjungti fono suliejimą",
    "Disable screenshare" : "Išjungti ekrano bendrinimą",
    "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Open Calendar" : "Atverti kalendorių",
    "Remove participant {name}" : "Šalinti dalyvį {name}",
    "Keep" : "Palikti",
    "Open dialpad" : "Atverti numerio rinkiklį",
    "Select a region" : "Pasirinkti regioną",
    "Submit" : "Pateikti",
    "Search …" : "Ieškoti…",
    "Message without mention" : "Rašyti be paminėjimo",
    "Mention myself" : "Paminėti save",
    "The conversation does not exist" : "Pokalbio nėra",
    "Join a conversation or start a new one!" : "Prisijunkite prie pokalbio arba pradėkite naują!",
    "Join a conversation or start a new one" : "Prisijunkite prie pokalbio arba pradėkite naują",
    "Error while joining the conversation" : "Klaida prisijungiant prie pokalbio",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud naudotojas",
    "User password" : "Naudotojo slaptažodis",
    "Matrix server URL" : "Matrix serverio URL",
    "User" : "Naudotojas",
    "Matrix channel" : "Matrix kanalas",
    "Team name" : "Komandos pavadinimas",
    "Channel name" : "Kanalo pavadinimas",
    "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
    "User name or email address" : "Naudotojo vardas ar el. pašto adresas",
    "Password" : "Slaptažodis",
    "Rocket.Chat channel" : "Rocket.Chat kanalas",
    "API token" : "API prieigos raktas",
    "Slack channel" : "Slack kanalas",
    "Server ID or name" : "Serverio ID ar pavadinimas",
    "Channel" : "Kanalas",
    "Login" : "Prisijungti",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC serverio URL (pvz., chat.freenode.net:6667)",
    "Nickname" : "Slapyvardis",
    "Connection password" : "Ryšio slaptažodis",
    "IRC channel" : "IRC kanalas",
    "Channel password" : "Kanalo slaptažodis",
    "Use TLS" : "Naudoti TLS",
    "Use SASL" : "Naudoti SASL",
    "Client ID" : "Kliento ID",
    "Team ID" : "Komandos ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber serverio URL",
    "MUC server URL" : "MUC serverio URL",
    "Jabber ID" : "Jabber ID",
    "Media" : "Medija",
    "Polls" : "Apklausos",
    "Voice messages" : "Balso žinutės",
    "Locations" : "Vietos",
    "Audio" : "Garso įrašai",
    "Other" : "Kita",
    "Show all media" : "Rodyti visą mediją",
    "Show all files" : "Rodyti visus failus",
    "Default" : "Numatytoji",
    "Group" : "Grupė",
    "Team" : "Komanda",
    "You: {lastMessage}" : "Jūs: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Leave this page" : "Išeiti iš šio puslapio",
    "Conversation password has been saved" : "Pokalbio slaptažodis įrašytas",
    "Conversation password has been removed" : "Pokalbio slaptažodis pašalintas",
    "Error occurred while saving conversation password" : "Įrašant pokalbio slaptažodį įvyko klaida",
    "Error while sharing file" : "Klaida bendrinant failą",
    "Could not post message: {errorMessage}" : "Nepavyko paskelbti žinutės: {errorMessage}",
    "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
    "Invitations sent" : "Pakvietimai išsiųsti",
    "{guest} (guest)" : "{guest} (svečias)",
    "Poll \"{name}\" was created by {user}. Click to vote" : "{user} sukūrė apklausą, pavadinimu „{name}“. Spustelėkite norėdami dalyvauti",
    "Failed to add reaction" : "Nepavyko pridėti reakcijos",
    "Failed to remove reaction" : "Nepavyko pašalinti reakcijos",
    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
    "Conversation link copied to clipboard" : "Pokalbio nuoroda nukopijuota į iškarpinę",
    "The link could not be copied" : "Nepavyko nukopijuoti nuorodos",
    "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
    "Do not disturb" : "Netrukdyti",
    "Away" : "Atsitraukęs",
    "Microphone {number}" : "Mikrofonas {number}",
    "Camera {number}" : "Kamera {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Atrodo, kad kalbate su išjungtu mikrofonu, įjunkite savo garsą, jei norite, kad kiti jus girdėtų",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tai užtrunka ilgiau, nei tikėtasi. Ar medijos leidimai jau yra suteikti (arba atmesti)? Jeigu taip, tuomet paleiskite savo naršyklę iš naujo, nes garsas ir vaizdas patiria nesėkmę",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo uždrausta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Error while accessing microphone & camera" : "Klaida gaunant prieigą prie mikrofono ir kameros",
    "This conversation is password-protected." : "Šis pokalbis yra apsaugotas slaptažodžiu.",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "%s Talk on your mobile devices" : "%s Pokalbiai jūsų mobiliuosiuose įrenginiuose",
    "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "__language_name__" : "Lietuvių",
    "Tasks" : "Užduotys",
    "Notes" : "Užrašai",
    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
    "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
    "Join »%s«" : "Prisijungti prie »%s«",
    "Talk settings" : "Pokalbių nustatymai",
    "Refresh devices list" : "Įkelti iš naujo įrenginių sąrašą",
    "Media settings" : "Medijos nustatymai",
    "Always show preview for this conversation" : "Visada rodyti šio pokalbio peržiūrą",
    "Set reminder for later today" : "Nustatyti priminimą šiandien vėliau",
    "Set reminder for tomorrow" : "Nustatyti priminimą rytoj",
    "Set reminder for this weekend" : "Nustatyti priminimą šį savaitgalį",
    "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "A week ago" : "Prieš savaitę",
    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dieną"],
    "Choose the folder in which attachments should be saved." : "Pasirinkite aplanką į kurį bus įrašomi priedai.",
    "Your privacy setting has been saved" : "Jūsų privatumo nustatymas įrašytas",
    "Choose devices" : "Pasirinkti įrenginius",
    "Browse …" : "Naršyti…",
    "Appearance" : "Išvaizda",
    "Sounds" : "Garsai",
    "Performance" : "Našumas",
    "Keyboard shortcuts" : "Spartieji klavišai",
    "Fullscreen the chat or call" : "Rodyti pokalbį ar skambutį visame ekrane",
    "Space bar" : "Tarpas",
    "Blur background" : "Sulieti foną",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
