<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => 'v23.0.1',
        'version' => '23.0.1.0',
        'reference' => '13e94e52759eb02f4aa139163038adf3ff7a5787',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => 'v23.0.1',
            'version' => '23.0.1.0',
            'reference' => '13e94e52759eb02f4aa139163038adf3ff7a5787',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'bamarni/composer-bin-plugin' => array(
            'pretty_version' => '1.8.3',
            'version' => '1.8.3.0',
            'reference' => 'e7ef9e012667327516c24e5fad9903a3bc91389d',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../bamarni/composer-bin-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cuyz/valinor' => array(
            'pretty_version' => '2.3.2',
            'version' => '2.3.2.0',
            'reference' => '3b9f3f54901371d589776502aab3da3a046801a7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../cuyz/valinor',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cweagans/composer-configurable-plugin' => array(
            'pretty_version' => '2.0.0',
            'version' => '2.0.0.0',
            'reference' => '15433906511a108a1806710e988629fd24b89974',
            'type' => 'library',
            'install_path' => __DIR__ . '/../cweagans/composer-configurable-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cweagans/composer-patches' => array(
            'pretty_version' => '2.0.0',
            'version' => '2.0.0.0',
            'reference' => 'bfa6018a5f864653d9ed899b902ea72f858a2cf7',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../cweagans/composer-patches',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'firebase/php-jwt' => array(
            'pretty_version' => 'v7.0.2',
            'version' => '7.0.2.0',
            'reference' => '5645b43af647b6947daac1d0f659dd1fbe8d3b65',
            'type' => 'library',
            'install_path' => __DIR__ . '/../firebase/php-jwt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
